@@ -3,8 +3,8 @@
 # Author          : Johan Vromans
 # Created On      : Tue Aug 30 12:44:57 2011
 # Last Modified By: Johan Vromans
-# Last Modified On: Tue Oct 18 09:25:28 2011
-# Update Count    : 138
+# Last Modified On: Mon Jul 25 21:13:47 2016
+# Update Count    : 164
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
@@ -16,7 +16,7 @@ use Carp;
 # Package name.
 my $my_package = 'SugarSync';
 # Program name and version.
-my ($my_name, $my_version) = qw( mirror_share 0.05 );
+my ($my_name, $my_version) = qw( mirror_share 0.06 );
 
 ################ Command line parameters ################
 
@@ -70,9 +70,14 @@ my ( $d_count ); # statistics
 my $cfg = Config::Tiny->read($config);
 
 my $so = SugarSync::API->new( $cfg->{auth}->{username},
-			      $cfg->{auth}->{password} );
+			      $cfg->{auth}->{password},
+			      $cfg->{api}->{accesskeyid},
+			      $cfg->{api}->{privateaccesskey},
+			      $cfg->{api}->{application},
+			    );
 
 my $shares = $so->get_receivedShares;
+
 foreach my $share ( @$shares ) {
     process_share($share);
 }
@@ -111,6 +116,11 @@ sub process_share {
     # Handle select/resume.
     return unless selectresume( $r->{displayName}, 0 );
 
+    # Treat as folder.
+    $r->{type} = 'folder';
+    process_collection([], $r);
+    return;
+
 #    my $f = $so->get_files( $r->{files} );
 #    warn Data::Dumper->Dump([$f],[qw(files)]);
 
@@ -297,13 +307,12 @@ sub ts_warn {
     foreach ( split( /\n/, join('',@_) ) ) {
 	CORE::warn( $ts, $_, "\n" );
     }
+    $ts;
 }
 
 sub ts_die {
-    my $ts = ts();
-    foreach ( split( /\n/, join('',@_) ) ) {
-	CORE::die( $ts, $_, "\n" );
-    }
+    my $ts = &ts_warn;
+    croak( $ts, "ABORT\n" );
 }
 
 sub wc_compile {
@@ -478,6 +487,11 @@ The config file should contain:
   username = your_sugarsync_user_name
   password = your_sugarsync_password
 
+  [api]
+  accesskeyid      = your_access_key_id
+  privateaccesskey = your_private_access_key
+  application      = your_application_id
+
 =SEE ALSO
 
 L<SugarSync::API>.
@@ -492,7 +506,7 @@ See L<SugarSync::API>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2011 Johan Vromans, all rights reserved.
+Copyright 2011,2016 Johan Vromans, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
